@@ -12,7 +12,7 @@ class NamedSession:
 		# mount root default
 		self.mount () # mount root
 
-	def mount (self, name = None, session_timeout = None, securekey = None, path = "/", domain = None, secure = False, http_only = False, extend = True):
+	def mount (self, name = None, session_timeout = None, securekey = None, path = "/", domain = None, secure = False, http_only = False, same_site = None, extend = True):
 		if self.__obj and name == self.__name:
 			return
 		self.__name = name
@@ -35,7 +35,7 @@ class NamedSession:
 		else:
 			obj = self.__get_notices (name, securekey)
 
-		obj.config (path, domain, secure, http_only)
+		obj.config (path, domain, secure, http_only, same_site)
 		self.__obj = obj
 
 	def exists (self, name = None):
